@@ -1,6 +1,3 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
 from .. import Provider as AutomotiveProvider
 
 
@@ -39,5 +36,5 @@ class Provider(AutomotiveProvider):
         # Saskatchewan
         '### ???',
         # Yukon
-        '???##'
+        '???##',
     )
