@@ -1,17 +1,14 @@
-from __future__ import unicode_literals
-
 from .. import BaseProvider
 
-
 localized = True
 
 
 class Provider(BaseProvider):
-    formats = ['{{first_name}} {{last_name}}', ]
+    formats = ['{{first_name}} {{last_name}}']
 
     first_names = ['John', 'Jane']
 
-    last_names = ['Doe', ]
+    last_names = ['Doe']
 
     def name(self):
         """
