@@ -30,208 +30,183 @@ class Provider(PersonProvider):
 
     formats = formats_male + formats_female
 
+    # 477 male first names, alphabetically.
+    # Source: Álvaro Mondéjar Rubio <mondejar1994@gmail.com>
     first_names_male = (
-        'Antonio',
-        'Jose',
-        'Manuel',
-        'Francisco',
-        'Juan',
-        'David',
-        'Jose Antonio',
-        'Jose Luis',
-        'Javier',
-        'Jesús',
-        'Francisco Javier',
-        'Daniel',
-        'Carlos',
-        'Miguel',
-        'Rafael',
-        'Jose Manuel',
-        'Alejandro',
-        'Pedro',
-        'Ángel',
-        'Miguel Ángel',
-        'Jose Maria',
-        'Fernando',
-        'Luís',
-        'Pablo',
-        'Sergio',
-        'Jorge',
-        'Alberto',
-        'Juan Carlos',
-        'Juan José',
-        'Diego',
-        'Alvaro',
-        'Adrián',
-        'Juan Antonio',
-        'Enrique',
-        'Raul',
-        'Ramon',
-        'Vicente',
-        'Ivan',
-        'Ruben',
-        'Andrés',
-        'Joaquin',
+        'Aarón', 'Abel', 'Abilio', 'Abraham', 'Adalberto',
+        'Adelardo', 'Adolfo', 'Adrián', 'Adán', 'Agapito', 'Agustín',
+        'Aitor', 'Albano', 'Albert', 'Alberto', 'Albino', 'Alcides',
+        'Ale', 'Alejandro', 'Alejo', 'Alex', 'Alfonso', 'Alfredo',
+        'Alonso', 'Amado', 'Amador', 'Amancio', 'Amando', 'Amaro',
+        'Ambrosio', 'Amor', 'Américo', 'Amílcar', 'Anacleto', 'Anastasio',
+        'Andrés', 'Andrés Felipe', 'Angelino', 'Anselmo', 'Antonio',
+        'Aníbal', 'Apolinar', 'Ariel', 'Aristides', 'Armando',
+        'Arsenio', 'Artemio', 'Arturo', 'Asdrubal', 'Atilio', 'Augusto',
+        'Aureliano', 'Aurelio', 'Baldomero', 'Balduino', 'Baltasar',
+        'Bartolomé', 'Basilio', 'Baudelio', 'Bautista', 'Benigno',
+        'Benito', 'Benjamín', 'Bernabé', 'Bernardino', 'Bernardo',
+        'Berto', 'Blas', 'Bonifacio', 'Borja', 'Bruno', 'Buenaventura',
+        'Calisto', 'Calixto', 'Camilo', 'Candelario', 'Carlito',
+        'Carlos', 'Carmelo', 'Casemiro', 'Cayetano', 'Cebrián',
+        'Cecilio', 'Ceferino', 'Celestino', 'Celso', 'Cesar', 'Che',
+        'Chema', 'Chucho', 'Chus', 'Chuy', 'Cipriano', 'Ciriaco',
+        'Cirino', 'Ciro', 'Ciríaco', 'Claudio', 'Clemente', 'Cleto',
+        'Clímaco', 'Conrado', 'Cornelio', 'Cosme', 'Cristian',
+        'Cristian', 'Cristóbal', 'Cruz', 'Curro', 'Custodio', 'Cándido',
+        'César', 'Damián', 'Dan', 'Dani', 'Daniel', 'Danilo', 'Darío',
+        'David', 'Demetrio', 'Desiderio', 'Diego', 'Dimas', 'Dionisio',
+        'Domingo', 'Donato', 'Duilio', 'Edelmiro', 'Edgardo', 'Edmundo',
+        'Edu', 'Eduardo', 'Efraín', 'Eladio', 'Eleuterio', 'Eligio',
+        'Eliseo', 'Eloy', 'Elpidio', 'Elías', 'Emigdio', 'Emiliano',
+        'Emilio', 'Enrique', 'Epifanio', 'Erasmo', 'Eric', 'Ernesto',
+        'Espiridión', 'Esteban', 'Eugenio', 'Eusebio', 'Eustaquio',
+        'Eutimio', 'Eutropio', 'Evaristo', 'Ezequiel', 'Fabio', 'Fabián',
+        'Fabricio', 'Faustino', 'Fausto', 'Federico', 'Feliciano',
+        'Felipe', 'Felix', 'Fermín', 'Fernando', 'Fidel', 'Fito',
+        'Flavio', 'Florencio', 'Florentino', 'Fortunato', 'Francisco',
+        'Francisco Javier', 'Francisco Jose', 'Fulgencio', 'Félix', 'Gabino',
+        'Gabriel', 'Galo', 'Gaspar', 'Gastón', 'Geraldo', 'Gerardo',
+        'Germán', 'Gervasio', 'Gerónimo', 'Gil', 'Gilberto', 'Glauco',
+        'Godofredo', 'Gonzalo', 'Goyo', 'Graciano', 'Gregorio',
+        'Guadalupe', 'Guillermo', 'Guiomar', 'Gustavo', 'Haroldo',
+        'Hector', 'Heliodoro', 'Heraclio', 'Herberto', 'Heriberto',
+        'Hermenegildo', 'Herminio', 'Hernando', 'Hernán', 'Hilario',
+        'Hipólito', 'Horacio', 'Hugo', 'Humberto', 'Héctor', 'Ibán',
+        'Ignacio', 'Iker', 'Ildefonso', 'Inocencio', 'Isaac', 'Isaías',
+        'Isidoro', 'Isidro', 'Ismael', 'Iván', 'Jacinto', 'Jacobo',
+        'Jafet', 'Jaime', 'Javi', 'Javier', 'Jenaro', 'Jeremías',
+        'Jerónimo', 'Jesús', 'Joan', 'Joaquín', 'Joel', 'Jonatan', 'Jordi',
+        'Jordán', 'Jorge', 'Jose', 'Jose Angel', 'Jose Antonio',
+        'Jose Carlos', 'Jose Francisco', 'Jose Ignacio', 'Jose Luis',
+        'Jose Manuel', 'Jose Miguel', 'Jose Ramón', 'Josep', 'Josué', 'José',
+        'José Antonio', 'José Luis', 'José Manuel', 'José Mari',
+        'José María', 'José Ángel', 'Juan', 'Juan Antonio',
+        'Juan Bautista', 'Juan Carlos', 'Juan Francisco', 'Juan José',
+        'Juan Luis', 'Juan Manuel', 'Juan Pablo', 'Juanito', 'Julio',
+        'Julio César', 'Julián', 'Kike', 'Lalo', 'Leandro', 'Leocadio',
+        'Leonardo', 'Leoncio', 'Leonel', 'Leopoldo', 'León', 'Lino',
+        'Lisandro', 'Lope', 'Lorenzo', 'Loreto', 'Lucas', 'Lucho',
+        'Luciano', 'Lucio', 'Luis', 'Luis Miguel', 'Luis Ángel', 'Lupe',
+        'Luís', 'Lázaro', 'Macario', 'Manolo', 'Manu', 'Manuel',
+        'Marc', 'Marcelino', 'Marcelo', 'Marcial', 'Marciano',
+        'Marcio', 'Marco', 'Marcos', 'Mariano', 'Marino', 'Mario',
+        'Martin', 'Martín', 'María', 'Mateo', 'Matías', 'Mauricio',
+        'Maxi', 'Maximiano', 'Maximiliano', 'Maximino', 'Melchor',
+        'Miguel', 'Miguel Ángel', 'Modesto', 'Mohamed', 'Moisés',
+        'Moreno', 'Máximo', 'Nacho', 'Nacio', 'Nando', 'Narciso',
+        'Natalio', 'Natanael', 'Nazaret', 'Nazario', 'Nicanor', 'Nico',
+        'Nicodemo', 'Nicolás', 'Nilo', 'Norberto', 'Noé', 'Néstor',
+        'Octavio', 'Olegario', 'Omar', 'Onofre', 'Osvaldo', 'Ovidio',
+        'Pablo', 'Paco', 'Pancho', 'Pascual', 'Pastor', 'Patricio',
+        'Paulino', 'Pedro', 'Pelayo', 'Pepe', 'Pepito', 'Plinio',
+        'Plácido', 'Poncio', 'Porfirio', 'Primitivo', 'Prudencio',
+        'Pánfilo', 'Pío', 'Quique', 'Quirino', 'Rafa', 'Rafael',
+        'Raimundo', 'Ramiro', 'Ramón', 'Raúl', 'Reinaldo', 'Remigio',
+        'Renato', 'René', 'Reyes', 'Reynaldo', 'Ricardo', 'Rico',
+        'Roberto', 'Rodolfo', 'Rodrigo', 'Rogelio', 'Rolando', 'Roldán',
+        'Román', 'Roque', 'Rosario', 'Rosendo', 'Ruben', 'Rubén',
+        'Rufino', 'Ruperto', 'Ruy', 'Régulo', 'Rómulo', 'Sabas',
+        'Salomón', 'Salvador', 'Samu', 'Samuel', 'Sancho', 'Sandalio',
+        'Santiago', 'Santos', 'Saturnino', 'Sebastian', 'Sebastián',
+        'Segismundo', 'Sergio', 'Seve', 'Severiano', 'Severino', 'Severo',
+        'Sigfrido', 'Silvestre', 'Silvio', 'Simón', 'Sosimo', 'Tadeo',
+        'Telmo', 'Teo', 'Teobaldo', 'Teodoro', 'Teodosio', 'Teófilo',
+        'Tiburcio', 'Timoteo', 'Tito', 'Tomás', 'Toni', 'Toribio', 'Toño',
+        'Trinidad', 'Tristán', 'Ulises', 'Urbano', 'Valentín', 'Valerio',
+        'Valero', 'Vasco', 'Venceslás', 'Vicente', 'Victor',
+        'Victor Manuel', 'Victoriano', 'Victorino', 'Vidal', 'Vinicio',
+        'Virgilio', 'Vito', 'Víctor', 'Wilfredo', 'Wálter', 'Xavier',
+        'Yago', 'Zacarías', 'Álvaro', 'Ángel', 'Édgar', 'Íñigo',
         'Óscar',
-        'Juan Manuel',
-        'Santiago',
-        'Eduardo',
-        'Victor',
-        'Roberto',
-        'Jaime',
-        'Francisco Jose',
-        'Ignacio',
-        'Mario',
-        'Alfonso',
-        'Salvador',
-        'Ricardo',
-        'Jordi',
-        'Marcos',
-        'Emilio',
-        'Julian',
-        'Julio',
-        'Guillermo',
-        'Tomás',
-        'Gabriel',
-        'Agustín',
-        'Jose Miguel',
-        'Felix',
-        'Jose Ramon',
-        'Gonzalo',
-        'Marc',
-        'Mohamed',
-        'Joan',
-        'Hugo',
-        'Ismael',
-        'Cristian',
-        'Nicolás',
-        'Mariano',
-        'Josep',
-        'Domingo',
-        'Samuel',
-        'Juan Francisco',
-        'Alfredo',
-        'Sebastian',
-        'Aitor',
-        'Jose Carlos',
-        'Martin',
-        'Felipe',
-        'Cesar',
-        'Hector',
-        'Jose Angel',
-        'Jose Ignacio',
-        'Victor Manuel',
-        'Gregorio',
-        'Luis Miguel',
-        'Iker',
-        'Jose Francisco',
-        'Juan Luis',
-        'Albert',
-        'Lorenzo',
-        'Alex',
-        'Xavier',
-        'Rodrigo')
+    )
 
+    # 477 female first names, alphabetically.
+    # Source: Álvaro Mondéjar Rubio <mondejar1994@gmail.com>
     first_names_female = (
-        'María',
-        'Carmen',
-        'Ana',
-        'Isabel',
-        'Dolores',
-        'Pilar',
-        'Josefa',
-        'Teresa',
-        'Rosa',
-        'Cristina',
-        'Ángeles',
-        'Antonia',
-        'Laura',
-        'Francisca',
-        'Elena',
-        'Mercedes',
-        'Luisa',
-        'Marta',
-        'Concepción',
-        'Rosario',
-        'Lucía',
-        'Juana',
-        'Manuela',
-        'Sara',
-        'Paula',
-        'Raquel',
-        'Beatriz',
-        'Eva',
-        'Patricia',
-        'Victoria',
-        'Rocio',
-        'Encarnacion',
-        'Julia',
-        'Belen',
-        'Silvia',
-        'Esther',
-        'Andrea',
-        'Montserrat',
-        'Nuria',
-        'Angela',
-        'Irene',
-        'Inmaculada',
-        'Mónica',
-        'Sandra',
-        'Margarita',
-        'Yolanda',
-        'Alba',
-        'Sonia',
-        'Alicia',
-        'Mar',
-        'Susana',
-        'Marina',
-        'Amparo',
-        'Natalia',
-        'Nieves',
-        'Gloria',
-        'Claudia',
-        'Soledad',
-        'Ines',
-        'Lourdes',
-        'Verónica',
-        'Carolina',
-        'Luz',
-        'Consuelo',
-        'Noelia',
-        'Asunción',
-        'Lorena',
-        'Sofia',
-        'Milagros',
-        'Catalina',
-        'Esperanza',
-        'Olga',
-        'Alejandra',
-        'Carla',
-        'Emilia',
-        'Fátima',
-        'Aurora',
-        'Blanca',
-        'Magdalena',
-        'Miriam',
-        'Lidia',
-        'Nerea',
-        'Clara',
-        'Daniela',
-        'Anna',
-        'Celia',
-        'Elisa',
-        'Eugenia',
-        'Josefina',
-        'Virginia',
-        'Purificación',
-        'Vanesa',
-        'Remedios',
-        'Trinidad',
-        'Gema',
-        'Adriana',
-        'Vicenta',
-        'Mireia',
-        'Begoña')
+        'Abigaíl', 'Abril', 'Adela', 'Adelaida', 'Adelia',
+        'Adelina', 'Adora', 'Adoración', 'Adriana', 'Agustina', 'Ainara',
+        'Ainoa', 'Aitana', 'Alba', 'Albina', 'Ale', 'Alejandra',
+        'Alexandra', 'Alicia', 'Alma', 'Almudena', 'Alondra', 'Amada',
+        'Amalia', 'Amanda', 'Amarilis', 'Amaya', 'Amelia', 'Amor',
+        'Amparo', 'América', 'Ana', 'Ana Belén', 'Ana Sofía', 'Anabel',
+        'Anastasia', 'Andrea', 'Angelina', 'Angelita', 'Angélica', 'Ani',
+        'Anita', 'Anna', 'Anselma', 'Antonia', 'Anunciación',
+        'Apolonia', 'Araceli', 'Arcelia', 'Ariadna', 'Ariel', 'Armida',
+        'Aroa', 'Aránzazu', 'Ascensión', 'Asunción', 'Aura',
+        'Aurelia', 'Aurora', 'Azahar', 'Azahara', 'Azeneth', 'Azucena',
+        'Beatriz', 'Begoña', 'Belen', 'Belén', 'Benigna', 'Benita',
+        'Bernarda', 'Bernardita', 'Berta', 'Bibiana', 'Bienvenida',
+        'Blanca', 'Brunilda', 'Brígida', 'Bárbara', 'Calista',
+        'Calixta', 'Camila', 'Candela', 'Candelaria', 'Candelas',
+        'Caridad', 'Carina', 'Carla', 'Carlota', 'Carmela', 'Carmelita',
+        'Carmen', 'Carmina', 'Carolina', 'Casandra', 'Catalina',
+        'Cayetana', 'Cecilia', 'Celestina', 'Celia', 'Charo', 'Chelo',
+        'Chita', 'Chus', 'Cintia', 'Clara', 'Clarisa', 'Claudia',
+        'Clementina', 'Cloe', 'Clotilde', 'Concepción', 'Concha',
+        'Constanza', 'Consuela', 'Consuelo', 'Coral', 'Corona',
+        'Crescencia', 'Cristina', 'Cruz', 'Custodia', 'Cándida', 'Dafne',
+        'Dalila', 'Daniela', 'Delfina', 'Delia', 'Diana', 'Dionisia',
+        'Dolores', 'Dominga', 'Domitila', 'Dora', 'Dorita', 'Dorotea',
+        'Dulce', 'Débora', 'Edelmira', 'Elba', 'Elena', 'Eli', 'Eliana',
+        'Eligia', 'Elisa', 'Elisabet', 'Elodia', 'Eloísa', 'Elvira',
+        'Ema', 'Emelina', 'Emilia', 'Emiliana', 'Emma', 'Emperatriz',
+        'Encarna', 'Encarnacion', 'Encarnación', 'Encarnita',
+        'Esmeralda', 'Esperanza', 'Estefanía', 'Estela', 'Ester', 'Esther',
+        'Estrella', 'Etelvina', 'Eufemia', 'Eugenia', 'Eulalia',
+        'Eusebia', 'Eva', 'Eva María', 'Evangelina', 'Evelia', 'Evita',
+        'Fabiana', 'Fabiola', 'Fanny', 'Febe', 'Felicia', 'Feliciana',
+        'Felicidad', 'Felipa', 'Felisa', 'Fernanda', 'Fidela', 'Filomena',
+        'Flavia', 'Flor', 'Flora', 'Florencia', 'Florentina', 'Florina',
+        'Florinda', 'Fortunata', 'Francisca', 'Fátima', 'Gabriela',
+        'Gala', 'Gema', 'Genoveva', 'Georgina', 'Gertrudis', 'Gisela',
+        'Gloria', 'Gracia', 'Graciana', 'Graciela', 'Griselda',
+        'Guadalupe', 'Guiomar', 'Haydée', 'Herminia', 'Hilda', 'Hortensia',
+        'Ignacia', 'Ileana', 'Imelda', 'Inmaculada', 'Inés', 'Irene',
+        'Iris', 'Irma', 'Isa', 'Isabel', 'Isabela', 'Isaura',
+        'Isidora', 'Itziar', 'Jacinta', 'Javiera', 'Jennifer', 'Jenny',
+        'Jessica', 'Jesusa', 'Jimena', 'Joaquina', 'Jordana', 'Josefa',
+        'Josefina', 'José', 'Jovita', 'Juana', 'Juanita', 'Judith',
+        'Julia', 'Juliana', 'Julie', 'Julieta', 'Lara', 'Laura',
+        'Leandra', 'Leire', 'Leocadia', 'Leonor', 'Leticia', 'Leyre',
+        'Lidia', 'Ligia', 'Lilia', 'Liliana', 'Lina', 'Loida', 'Lola',
+        'Lorena', 'Lorenza', 'Loreto', 'Lourdes', 'Luciana', 'Lucila',
+        'Lucía', 'Luisa', 'Luisina', 'Luna', 'Lupe', 'Lupita', 'Luz',
+        'Macarena', 'Macaria', 'Magdalena', 'Maite', 'Malena', 'Mamen',
+        'Manola', 'Manu', 'Manuela', 'Manuelita', 'Mar', 'Marcela',
+        'Marcia', 'Margarita', 'Mariana', 'Marianela', 'Maribel',
+        'Maricela', 'Maricruz', 'Marina', 'Marisa', 'Marisela', 'Marisol',
+        'Maristela', 'Marita', 'Marta', 'Martina', 'Martirio', 'María',
+        'María Belén', 'María Carmen', 'María Cristina',
+        'María Del Carmen', 'María Dolores', 'María Fernanda', 'María Jesús',
+        'María José', 'María Luisa', 'María Manuela', 'María Pilar',
+        'María Teresa', 'María Ángeles', 'Matilde', 'Maura', 'Maxi', 'Mayte',
+        'Melania', 'Melisa', 'Mercedes', 'Merche', 'Micaela', 'Miguela',
+        'Milagros', 'Mireia', 'Miriam', 'Mirta', 'Modesta', 'Montserrat',
+        'Morena', 'Máxima', 'Mónica', 'Nadia', 'Narcisa', 'Natalia',
+        'Natividad', 'Nayara', 'Nazaret', 'Nerea', 'Nereida', 'Nicolasa',
+        'Nidia', 'Nieves', 'Nilda', 'Noa', 'Noelia', 'Noemí', 'Nuria',
+        'Nydia', 'Nélida', 'Obdulia', 'Octavia', 'Odalis', 'Odalys',
+        'Ofelia', 'Olalla', 'Olga', 'Olimpia', 'Olivia', 'Oriana',
+        'Otilia', 'Paca', 'Pacífica', 'Palmira', 'Paloma', 'Paola',
+        'Pascuala', 'Pastora', 'Patricia', 'Paula', 'Paulina', 'Paz',
+        'Pepita', 'Perla', 'Perlita', 'Petrona', 'Piedad', 'Pilar',
+        'Pili', 'Primitiva', 'Priscila', 'Prudencia', 'Purificación',
+        'Pía', 'Rafaela', 'Ramona', 'Raquel', 'Rebeca', 'Regina',
+        'Reina', 'Remedios', 'Renata', 'Reyes', 'Reyna', 'Ricarda',
+        'Rita', 'Roberta', 'Rocío', 'Rosa', 'Rosa María', 'Rosalina',
+        'Rosalinda', 'Rosalva', 'Rosalía', 'Rosario', 'Rosaura', 'Rosenda',
+        'Roxana', 'Rufina', 'Ruperta', 'Ruth', 'Sabina', 'Salomé',
+        'Salud', 'Samanta', 'Sandra', 'Sara', 'Sarita', 'Saturnina',
+        'Selena', 'Serafina', 'Silvia', 'Socorro', 'Sofía', 'Sol',
+        'Soledad', 'Sonia', 'Soraya', 'Susana', 'Susanita', 'Tamara',
+        'Tania', 'Tatiana', 'Tecla', 'Teodora', 'Tere', 'Teresa',
+        'Teresita', 'Teófila', 'Tomasa', 'Trini', 'Trinidad', 'Valentina',
+        'Valeria', 'Vanesa', 'Vera', 'Verónica', 'Vicenta', 'Victoria',
+        'Vilma', 'Violeta', 'Virginia', 'Visitación', 'Viviana',
+        'Ximena', 'Xiomara', 'Yaiza', 'Yolanda', 'Yésica', 'Yéssica',
+        'Zaida', 'Zaira', 'Zoraida', 'África', 'Ágata', 'Águeda',
+        'Ámbar', 'Ángela', 'Ángeles', 'Áurea', 'Íngrid', 'Úrsula',
+    )
 
     first_names = first_names_male + first_names_female
 
