@@ -1,19 +1,35 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from collections import OrderedDict
 
 from .. import Provider as PersonProvider
 
 
+# See transliteration table https://en.wikipedia.org/wiki/Romanization_of_Russian#Transliteration_table
+def translit(text):
+    translit_dict = {
+      'а': 'a', 'б': 'b', 'в': 'v', 'г': 'g', 'д': 'd', 'е': 'e', 'ё': 'e', 'ж': 'zh', 'з': 'z', 'и': 'i', 'й': 'y',
+      'к': 'k', 'л': 'l', 'м': 'm', 'н': 'n', 'о': 'o', 'п': 'p', 'р': 'r', 'с': 's', 'т': 't', 'у': 'u', 'ф': 'f',
+      'х': 'kh', 'ц': 'ts', 'ч': 'ch', 'ш': 'sh', 'щ': 'shch', 'ъ': '', 'ы': 'y', 'ь': '', 'э': 'e', 'ю': 'yu',
+      'я': 'ya', 'А': 'A', 'Б': 'B', 'В': 'V', 'Г': 'G', 'Д': 'D', 'Е': 'Ye', 'Ë': 'E', 'Ж': 'Zh', 'З': 'Z', 'И': 'I',
+      'Й': 'Y', 'К': 'K', 'Л': 'L', 'М': 'M', 'Н': 'N', 'О': 'O', 'П': 'P', 'Р': 'R', 'С': 'S', 'Т': 'T', 'У': 'U',
+      'Ф': 'F', 'Х': 'Kh', 'Ц': 'Ts', 'Ч': 'Ch', 'Ш': 'Sh', 'Щ': 'Shch', 'Ы': 'Y', 'Э': 'E', 'Ю': 'Yu', 'Я': 'Ya',
+      ' ': ' ', '-': '-', "'": "'",
+     }
+    for letter in text:
+        text = text.replace(letter, translit_dict[letter])
+    return text
+
+
 class Provider(PersonProvider):
     formats_male = OrderedDict((
-        ('{{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.97),
-        ('{{prefix_male}} {{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.03),
+        ('{{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.49),
+        ('{{first_name_male}} {{middle_name_male}} {{last_name_male}}', 0.49),
+        ('{{prefix_male}} {{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.02),
     ))
 
     formats_female = OrderedDict((
-        ('{{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.97),
-        ('{{prefix_female}} {{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.03),
+        ('{{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.49),
+        ('{{first_name_female}} {{middle_name_female}} {{last_name_female}}', 0.49),
+        ('{{prefix_female}} {{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.02),
     ))
 
     # Using random_element's dictionary weighting means that the
@@ -77,7 +93,7 @@ class Provider(PersonProvider):
         'Фрол', 'Харитон', 'Харлампий', 'Христофор', 'Чеслав', 'Эдуард',
         'Эммануил', 'Эмиль', 'Эраст', 'Эрнест', 'Эрнст', 'Ювеналий',
         'Юлиан', 'Юлий', 'Юрий', 'Яков', 'Ян', 'Якуб',
-        'Януарий', 'Ярополк', 'Ярослав'
+        'Януарий', 'Ярополк', 'Ярослав',
     )
 
     first_names_female = (
@@ -93,7 +109,7 @@ class Provider(PersonProvider):
         'Наталья', 'Нина', 'Нинель', 'Нонна', 'Оксана', 'Октябрина',
         'Олимпиада', 'Ольга', 'Пелагея', 'Полина', 'Прасковья', 'Раиса',
         'Регина', 'Светлана', 'Синклитикия', 'София', 'Таисия', 'Тамара',
-        'Татьяна', 'Ульяна', 'Фаина', 'Феврония', 'Фёкла', 'Элеонора', 'Эмилия', 'Юлия'
+        'Татьяна', 'Ульяна', 'Фаина', 'Феврония', 'Фёкла', 'Элеонора', 'Эмилия', 'Юлия',
     )
 
     first_names = first_names_male + first_names_female
@@ -148,7 +164,7 @@ class Provider(PersonProvider):
         'Мясников', 'Лихачев', 'Буров', 'Сысоев', 'Фомичев',
         'Русаков', 'Стрелков', 'Гущин', 'Тетерин', 'Колобов',
         'Субботин', 'Фокин', 'Блохин', 'Селиверстов', 'Пестов',
-        'Кондратьев', 'Силин', 'Меркушев', 'Лыткин', 'Туров'
+        'Кондратьев', 'Силин', 'Меркушев', 'Лыткин', 'Туров',
     )
 
     last_names_female = (
@@ -198,7 +214,7 @@ class Provider(PersonProvider):
         'Бурова', 'Сысоева', 'Фомичева', 'Русакова', 'Стрелкова', 'Гущина',
         'Тетерина', 'Колобова', 'Субботина', 'Фокина', 'Блохина',
         'Селиверстова', 'Пестова', 'Кондратьева', 'Силина', 'Меркушева',
-        'Лыткина', 'Турова'
+        'Лыткина', 'Турова',
     )
 
     last_names = last_names_male + last_names_female
@@ -231,7 +247,7 @@ class Provider(PersonProvider):
         'Филиппович', 'Фокич', 'Фомич', 'Фролович', 'Харитонович', 'Харламович',
         'Харлампович', 'Харлампьевич', 'Чеславович', 'Эдгардович', 'Эдгарович',
         'Эдуардович', 'Юлианович', 'Юльевич', 'Яковлевич', 'Якубович',
-        'Ярославович'
+        'Ярославович',
     )
 
     middle_names_female = (
@@ -251,12 +267,12 @@ class Provider(PersonProvider):
         'Руслановна', 'Романовна', 'Рудольфовна', 'Святославовна', 'Сергеевна',
         'Степановна', 'Семеновна', 'Станиславовна', 'Тарасовна', 'Тимофеевна',
         'Тимуровна', 'Федоровна', 'Феликсовна', 'Филипповна', 'Харитоновна',
-        'Эдуардовна', 'Эльдаровна', 'Юльевна', 'Юрьевна', 'Яковлевна'
+        'Эдуардовна', 'Эльдаровна', 'Юльевна', 'Юрьевна', 'Яковлевна',
     )
 
     middle_names = middle_names_male + middle_names_female
 
-    prefixes_male = ('г-н.', 'тов.')
+    prefixes_male = ('г-н', 'тов.')
 
     prefixes_female = ('г-жа', 'тов.')
 
